#include <looptime.h>
#include <linscale.h>

/* 6/27/2015 - Modified by AIAA OC Rocketry
             Directions referenced to top of MMA7361LC 3 axis accelerometer sitting flat on a table using the accelerometers reference of "x", "y", and "z"
                                              --------------------
                                        GND   |1-GND       Vdd-10|  3.3 VDC
              ^                               |                  |
              | (towards top of board)  AN1   |2-X         Test-9|  NC
              |                               |                  |
              <----  (to the left)      AN2   |3-Y         GSel-8|  Center of 1K Ohm Divider to ~6 on UNO (to scale Arduino Uno 5V to MMA7361LC at 3.3V)
                                              |                  |
              0      (up off the table) AN3   |4-Z        Sleep-7|  3.3 VDC
                                              |                  |
                                        GND   |5-GND  0g-Detect-6|  NC
                                              --------------------

    Wiring (if you are using a breadboard for testing instead of the sketch:
        MMA7316LC     Arduino
            1           GND
            2           AN1
            3           AN2
            4           AN3
            5           GND
            6           No Connect
            7           3.3 VDC
            8           Center of two 1K ohm resistors in series (See Version 4 shield schematic for R1 and R2)
                          Top of 1 resistor to Arduino Pin 8
                          Center of resistors to MMA7316LC pin 8
                          Bottom of other resistor to GND
            9           No Connect
            10          3.3 VDC
    Also added ability for conditional compile to include each axis individually to make it easier to see which axis is affected by movement
    Also added defines for the A/D channels instead of having values hard coded

    Instructions;
         1 - Wire the MMA7361L per the Arduino Shield Version 4 schematic
         2 - Compile and upload this sketch
         3 - Start the Serial Monitor program to make certain you are getting data from the accceleromater
         4 - You can enable or disable each axis individually and make certain values change when you move the accelerometer in that axis
         5 - In Calib15g6g you will calibrate each of the 1.5g and 6g ranges against the three axes of the accelerometer (x, y, and z)
             You will do this by using gravity (1g) and orienting each of the axes "up" and "down" with respect to the pull of the earth's gravity of 1g
             Compile and run the Calib15g6g sketch which will give you calibration values for +1g and -1g for the 1.5g and 6g ranges output will look like:
                   6g results
                   ----------------------
                   x: 149 313 476
                   y: 157 324 486
                   z: 184 349 508
                   1.5 g results
                   ----------------------
                   x: 149 311 476
                   y: 156 324 486
                   z: 184 348 508
             The first value in any line is the -1g value for that range (6g or 1,5g) and that axis (x or y or z); the last value in that line is the +1g value
         6 - Insert those values in the linscaleinit() line below
         7 - linscaleinit(&acc15x,184,-1.0,508,1.0);
                                   |        |__________+1g value from Calib15g6g for x
                                   |___________________-1g value from Calib15g6g for x
         8 - Repeat for y and z values
         9 - Rerun this sketch and verify a reading close to +1g and -1g for each orientation (per the calib15g6g sketch - you may need to adjust a little
*/
/*
 simple program which read acc x,y,z
 convert to float by scaling parms 
 (use -1g and 1g meas by cansat/calibacc
 This program to auto switch between 1.5 and 6.0g
 
 NB NBNB Calib
 
 Use program  JDN sketches -> mma7631 ->calib15g6g
 */

struct linscaletp acc15x,acc15y,acc15z,
acc6x, acc6y, acc6z;

// Define ENABLE AND DISABLE for conditional compiles
#define ENABLE 1
#define DISABLE 0

// Define which A/D port is connected to the X, Y, and Z axes
#define AccelXaxis 1 // CanSat "Z" axis
#define AccelYaxis 2 // CanSat "X" axis
#define AccelZaxis 3 // CanSat "Y" axis

// for debugging - set all to ENABLE for operation - otherwise set only the one you want to see to ENABLE
#define Print_Xaxis ENABLE
#define Print_Yaxis ENABLE
#define Print_Zaxis ENABLE

// for debugging - set the time between sending data (in milliseconds - lower number is faster) Default is very fast (50); larger number lets you see data easier
#define LoopTime 50



void setup()
{
    pinMode(8,OUTPUT);
    digitalWrite(8,LOW);
    Serial.begin(9600);
  
// for -1g (first calibration number below) a larger calibration # below gives larger negative acceleration returned
// for +1g (second calibration number below) a larger calibration # gives smaller acceleration
// Observed: approximately 20 calibration points gives .11 swing in output - approximately 2 calibration points per .1 output swing (eg: 507 = .88  497 - .94   487 = .99)
  linscaleinit(&acc15x,184,-1.0,508,1.0); // this is the first value returned in Serial Monitor (on side - pins 1-5 UP for +1g value)
  linscaleinit(&acc15y,149,-1.0,476,1.0); // this is the second value returned in Serial Monitor (on back - components UP for +1g value)
  linscaleinit(&acc15z,157,-1.0,486,1.0); // this is the third value returned in Serial Monitor (on end - pins 1 & 10 UP for +1g value)

  digitalWrite(8,HIGH);
  linscaleinit(&acc6z,184,-1.0,508,1.0);
  linscaleinit(&acc6z,149,-1.0,476,1.0);
  linscaleinit(&acc6z,157,-1.0,486,1.0);

  digitalWrite(8,LOW);
}

float ax,ay,az,r;
void loop()
{
  ax = linscale(analogRead(AccelYaxis),&acc15x);
  ay = linscale(analogRead(AccelZaxis),&acc15y);
  az = linscale(analogRead(AccelXaxis),&acc15z);
  
  if ( (1.5 < abs(ax)) || (1.5 < abs(ay)) || (1.5 < abs(az)) ) {

    digitalWrite(8,HIGH);

    ax = linscale(analogRead(AccelYaxis),&acc6x);
    ay = linscale(analogRead(AccelZaxis),&acc6y);
    az = linscale(analogRead(AccelXaxis),&acc6z);

    digitalWrite(8,LOW);
  }

#if Print_Xaxis
  Serial.print(ax); 
  Serial.print(" , ");
#endif

#if Print_Yaxis
  Serial.print(ay); 
  Serial.print(" , ");
#endif

#if Print_Zaxis
  Serial.print(az); 
  Serial.print(" , ");
#endif
  r = sqrt(ax*ax+ay*ay+az*az);
  Serial.println(r);
  looptime(LoopTime);
}





